==> haskell-wreq-0.5.4.3-139-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wreq
version:              0.5.4.3
visibility:           public
id:                   wreq-0.5.4.3-17a7Wx3iqLv2LIP4vPOrYD
key:                  wreq-0.5.4.3-17a7Wx3iqLv2LIP4vPOrYD
license:              BSD-3-Clause
copyright:            2014 Bryan O'\''Sullivan
maintainer:           bos@serpentine.com
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/wreq
synopsis:             An easy-to-use HTTP client library.
description:
    .
    A web client library that is designed for ease of use.
    .
    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>
    .
    Features include:
    .
    * Simple but powerful `lens`-based API
    .
    * A solid test suite, and built on reliable libraries like
      http-client and lens
    .
    * Session handling includes connection keep-alive and pooling, and
      cookie persistence
    .
    * Automatic response body decompression
    .
    * Powerful multipart form and file upload handling
    .
    * Support for JSON requests and responses, including navigation of
      schema-less responses
    .
    * Basic and OAuth2 bearer authentication
    .
    * Early TLS support via the tls package

category:             Web
abi:                  9ff827a63d2a7daddaf1bb6d9e1a659e
exposed:              True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types

hidden-modules:
    Network.Wreq.Internal Network.Wreq.Internal.AWS
    Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
    Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
    Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wreq-0.5.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wreq-0.5.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wreq-0.5.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wreq
hs-libraries:         HSwreq-0.5.4.3-17a7Wx3iqLv2LIP4vPOrYD
depends:
    aeson-2.1.2.1-2ooOAwlErgbHj6Tyvuh2I5
    attoparsec-0.14.4-FDtC6GeLACtJHW3icA3qMM
    authenticate-oauth-1.7-CLsf8X1ZKH7Ce7zIG2I0EI base-4.17.2.1
    base16-bytestring-1.0.2.0-LQzuWooFmdALTFyXCNHSon
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-JUsvO4q6QZv9oNQva346P6
    containers-0.6.7 crypton-1.0.2-Ehe8sflngVC8befumTC8Y7
    exceptions-0.10.5 ghc-prim-0.9.1
    hashable-1.4.4.0-CTf4tWLvOCwE4B8hp3PoEK
    http-client-0.7.18-LbIjfqgkVH6EQZrPuBb65p
    http-client-tls-0.3.6.4-AoW9RXZ494d6jfm3w17fZv
    http-types-0.12.4-8FTU05okzyoIwQtiG4S4B5
    lens-5.3-AIJaKrXjlD5HhDEbilmzm0
    lens-aeson-1.2.3-1gwuGdSgkTIBOP2V0ImfL3
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    psqueues-0.2.8.1-2snP1VXSxdwJdHDhtKmpIH template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-1zJhxgkP2bvGiOhYof1wNA
    unordered-containers-0.2.20-5aRSzj1YCHv4h2N6lFa6Hx

haddock-interfaces:   /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html:         /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wreq-0.5.4.3-140-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wreq
version:              0.5.4.3
visibility:           public
id:                   wreq-0.5.4.3-I2TDtTIlHtWBeLjxfYP7lx
key:                  wreq-0.5.4.3-I2TDtTIlHtWBeLjxfYP7lx
license:              BSD-3-Clause
copyright:            2014 Bryan O'\''Sullivan
maintainer:           bos@serpentine.com
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/wreq
synopsis:             An easy-to-use HTTP client library.
description:
    .
    A web client library that is designed for ease of use.
    .
    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>
    .
    Features include:
    .
    * Simple but powerful `lens`-based API
    .
    * A solid test suite, and built on reliable libraries like
      http-client and lens
    .
    * Session handling includes connection keep-alive and pooling, and
      cookie persistence
    .
    * Automatic response body decompression
    .
    * Powerful multipart form and file upload handling
    .
    * Support for JSON requests and responses, including navigation of
      schema-less responses
    .
    * Basic and OAuth2 bearer authentication
    .
    * Early TLS support via the tls package

category:             Web
abi:                  aa84f8ea812a62708bc51ca3b9263133
exposed:              True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types

hidden-modules:
    Network.Wreq.Internal Network.Wreq.Internal.AWS
    Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
    Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
    Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wreq-0.5.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wreq-0.5.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wreq-0.5.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wreq
hs-libraries:         HSwreq-0.5.4.3-I2TDtTIlHtWBeLjxfYP7lx
depends:
    aeson-2.1.2.1-F9MXb1A8ug6GkYytoGh4jA
    attoparsec-0.14.4-Ie40PJLLZWYz4b9BsvrTL
    authenticate-oauth-1.7-K1FMTI0PyStF2L1A0Prwpa base-4.17.2.1
    base16-bytestring-1.0.2.0-5vlLRlPqKexCB3C79nTCDd
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-Az6gtf7HlYzJEXK7A4kQ5x
    containers-0.6.7 crypton-1.0.2-7o8Jrkh7igGF3aYIPFY8Rt
    exceptions-0.10.5 ghc-prim-0.9.1
    hashable-1.4.4.0-FG1b1gw3lrmKPDYe5KupbE
    http-client-0.7.18-GDC9HFEBSpxLTKz1dfTnFD
    http-client-tls-0.3.6.4-692MveemGYY98CzdRZjDd3
    http-types-0.12.4-1P1R4JUxLuAK31ciTRSGza
    lens-5.3-HdczP0no6IA6OsB2lfUnLL
    lens-aeson-1.2.3-LUkr4SP5UP52IeCA7OTMeC
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    psqueues-0.2.8.1-Ju1D7e4VgJK9EcVwbDeHsy template-haskell-2.19.0.0
    text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-1zJhxgkP2bvGiOhYof1wNA
    unordered-containers-0.2.20-Kb1zmdIZFsX5Z4trT8w0xB

haddock-interfaces:   /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html:         /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
